#
# spec file for package ktoblzcheck
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ktoblzcheck
%define libsoname lib%{name}1
Summary:        A library to check account numbers and bank codes of German banks
License:        LGPL-2.1-only
Group:          Productivity/Office/Finance
Version:        1.53
Release:        1.11
Source:         http://downloads.sourceforge.net/project/%{name}/%{name}-%{version}.tar.gz
URL:            http://ktoblzcheck.sourceforge.net
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  pkg-config
BuildRequires:  python3-devel

%description
KtoBLZCheck is a library to check account numbers and bank codes
of German banks. Both a library for other programs as well as a
short command-line tool is available. It is possible to check
pairs of account numbers and bank codes (BLZ) of German banks,
and to map bank codes (BLZ) to the clear-text name and location
of the bank.

%package devel
Summary:        KtoBLZCheck development files
Group:          Development/Libraries/C and C++
Requires:       %{libsoname} = %{version}
Provides:       %{libsoname}-devel = %{version}
Obsoletes:      %{libsoname}-devel < %{version}

%description devel
Libraries, includes etc to develop with ktoblzcheck library.

%package -n %{libsoname}
Summary:        Shared Libraries for ktoblzcheck
Group:          System/Libraries

%description -n %{libsoname}
This package contains shared Libraries for ktoblzcheck.

%package -n python3-%{name}
Summary:        KtoBLZCheck python-bindings
Group:          Development/Libraries/Python
Requires:       %{libsoname} = %{version}
Requires:       %{name} = %{version}
Obsoletes:      python-%{name} < %{version}

%description -n python3-%{name}
This package contains the python-bindings for ktoblzcheck.

%prep
%setup -q

%build
%cmake -DINSTALL_RAW_BANKDATA_FILE=1 -DENABLE_BANKDATA_DOWNLOAD=0
make %{?_smp_mflags}

%install
%cmake_install

%fdupes -s %{buildroot}

%post -n %{libsoname} -p /sbin/ldconfig

%postun -n %{libsoname} -p /sbin/ldconfig

%files
%doc AUTHORS ChangeLog NEWS README.md
%license COPYING
%{_bindir}/%{name}
%{_bindir}/ibanchk
%{_mandir}/man1/%{name}.1*
%{_mandir}/man1/ibanchk.1*
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/ibandata.txt
%{_datadir}/%{name}/bankdata_*.txt
%{_datadir}/%{name}/blz_*.txt

%files -n %{libsoname}
%{_libdir}/*.so.*

%files devel
%doc AUTHORS ChangeLog NEWS README.md
%license COPYING
%{_libdir}/*.so
%{_libdir}/pkgconfig/%{name}.pc
%{_includedir}/%{name}.h
%{_includedir}/iban.h
%{_libdir}/cmake/KtoBlzCheck

%files -n python3-%{name}
%{python3_sitearch}/*

%changelog
* Fri Oct  8 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.53:
  * Update bankdata files
  * ibanchk: add '--file' command line option
  * Add python 3 support
  * Add link to german bank data description
  * Add manual page for ibanchk
  * Install ibanchk executable
- Rename python-ktoblzcheck package to python3-ktoblzcheck.
* Mon Jan 20 2020 Ralf Habacker <ralf.habacker@freenet.de>
- update to 1.51
  * Add fetching of sepa providers and install them as csv file
  * Add supported short options to ktoblzcheck usage output
  * Fix finding files on windows
  * Fix bug not finding default bank data file when XDG_DATA_DIRS is not set (sf/ktoblzcheck#2)
* Thu Sep 19 2019 Ralf Habacker <ralf.habacker@freenet.de>
- update to 1.50
  * Add cmake option to install the raw bankdata file
  * Add german iban check
  * Add support for environment variable XDG_DATA_DIRS also on Windows required by test cases
  * Add support for running cross compiled applications on linux
  * Completed cmake support on Linux and Windows
  * Dropped autotools build system
  * Fix structure documentation in ibandata.txt
  * Fix test cases
  * Merge text from README*, INSTALL* into README.md
  * New bank data file added
  * Replaced perl scripts by python scripts to reduce the number of requirements
  * Update doxygen config file to version 1.8.14
  * Use README.md as main page for doxygen
* Sat Feb  4 2017 jengelh@inai.de
- Remove redundant %%clean. Use %%_smp_mflags for parallel build.
* Fri Nov 18 2016 chris@computersalat.de
- update to 1.48
  * format spec file
  * add libsoname
  * rename devel pkg (name-devel) and add Provides/Obsoletes
* Tue Dec 20 2011 coolo@suse.com
- remove call to suse_update_config (very old work around)
* Mon Oct 10 2011 Nico.Laus.2001@gmx.de
- update to 1.36:
  * Replace assertions with graceful failures
- fixed rpmlint warning about missing pkg-config
* Mon Sep 12 2011 anixx@opensuse.org
- update to 1.35
* Sat Aug 14 2010 beineri@opensuse.org
- update to 1.2.8
  * New bank data file added. Fixed method 96 and 63.
* Thu Jul  8 2010 beineri@opensuse.org
- update to 1.2.7
  * Updated bankdata file, now valid from 2010-06-07 onwards.
  * Modified Methods C6 and D1, add method D4
* Sun Apr 11 2010 beineri@opensuse.org
- update to 1.26
  * Fix broken loading of current bankdata file by dynamically
    creating the list of current files at compile time.
  * Updated bankdata file, now valid from 2010-03-08 onwards.
  * Fix method 23 (zero padding must come at end, not beginning).
* Mon Dec 21 2009 Nico.Laus.2001@gmx.de
- restored openSUSE package header
* Fri Dec  4 2009 Nico.Laus.2001@gmx.de
- update to 1.24
  * Updated bankdata file, now valid from 2009-12-07 onwards.
- applied package layout from packman
* Mon Sep 21 2009 beineri@opensuse.org
- update to 1.23:
  * Updated bankdata file, now valid from 2009-09-07 onwards.
* Mon Jul 27 2009 beineri@opensuse.org
- update to 1.22:
  * Updated bankdata file, now valid from 2009-06-08 onwards.
* Fri Feb 13 2009 coolo@suse.de
- update to 1.21:
  Method C6 modified to include March'09 update.
  New bank data file added.
  Two new calculation methods have been added.
* Thu Jan 29 2009 crrodriguez@suse.de
- remove static libraries and "la" files
* Sun Aug 17 2008 stbinner@suse.de
- update to version 1.19:
  * Two new calculation methods have been added.
  * Online-update accepts wget instead of lynx as well.
  * New bank data file added.
* Mon Jun 16 2008 stbinner@suse.de
- update to version 1.18:
  * Updated bankdata file, now valid from 2008-06-09 onwards.
  * New methods C8 and C9, valid from 6. June 2008.
* Tue Mar 25 2008 stbinner@suse.de
- update to version 1.17: Handling of the timezone has been fixed.
  Code had been cleaned up for gcc-4.3. New bank data file added.
* Fri Nov  9 2007 dmueller@suse.de
- fix build with gcc 4.3
* Thu Nov  8 2007 stbinner@suse.de
- update to version 1.16:
  * Updated bankdata file, now valid from 2007-12-03 onwards.
  * New methods C7. Valid from 3. December 2007.
* Tue Oct 23 2007 stbinner@suse.de
- fix build with gcc 4.3
* Wed Sep 26 2007 stbinner@suse.de
- update to version 1.15:
  * New methods C5 and C6. Valid from 3. September 2007.
  * Fixing method 74/Ausnahme to accept leading zeros.
  * Converted methods 74 and 87 to two-arguent notation.
  * Updated bankdata file, now valid from 2007-09-03 onwards.
* Mon Jul  9 2007 stbinner@suse.de
- update to version 1.14:
  * Updated bankdata file, now valid from 2007-06-04 onwards.
  * Fixing method 74/Ausnahme: 6-digit Account numbers with last
    number [5-9] computed incorrect results.
* Mon Feb 19 2007 stbinner@suse.de
- update to version 1.13:
  * Updated bankdata file, now valid from 2007-03-05 onwards.
  * Fixing wrong implementation of Pruefmethode 02 and similar
    methods 04, 07, 14, 58, 85/a, A2/v2, B2/v1, B4/v2, C3/v2, C4/v2.
  * New methods C3 and C4. Valid from 5. March 2007.
  * New version of Pruefzifferberechnungsmethode 57 used by Citybank.
* Tue Dec  5 2006 stbinner@suse.de
- update to version 1.12:
  * Updated bankdata file, now valid from 2006-12-04 onwards.
  * configure.ac: Fix/improve internal libs flags
  * src/python/ktoblzcheck.py: Fix python wrapper with ctypes>=0.9.9
* Wed Aug 16 2006 stbinner@suse.de
- update to version 1.11:
  * Updated bankdata file, now valid from 2006-09-04 onwards.
* Mon Jul 24 2006 stbinner@suse.de
- update to version 1.10:
  * Updated bankdata file
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan  2 2006 stbinner@suse.de
- update to version 1.9
* Sat Dec 17 2005 stbinner@suse.de
- fix filelist
* Thu Oct 20 2005 stbinner@suse.de
- New package, initial version 1.7
